@@ -17,7 +17,7 @@ use serde_json::Value;
 use super::*;
 use command::{expand_fields, GeneralOpt, OutputFormat};
 use common::logutil::get_logger;
-use model::{Collector, Queriable};
+use model::{Collector, EnumIter, Queriable};
 use print::HasRenderConfigForDump;
 use tmain::Dumper;
 
@@ -35,7 +35,7 @@ fn test_dump_sys_content() {
     for subquery_id in model::SingleCpuModelFieldId::unit_variant_iter() {
         fields.push(DumpField::FieldId(model::SystemModelFieldId::Cpus(
             model::VecFieldId {
-                idx: 31,
+                idx: Some(31),
                 subquery_id,
             },
         )));
@@ -86,7 +86,7 @@ fn test_dump_sys_titles() {
         .chain(
             model::SingleCpuModelFieldId::unit_variant_iter().map(|subquery_id| {
                 DumpField::FieldId(model::SystemModelFieldId::Cpus(model::VecFieldId {
-                    idx: 31,
+                    idx: Some(31),
                     subquery_id,
                 }))
             }),
@@ -386,9 +386,9 @@ fn traverse_cgroup_tree(model: &model::CgroupModel, jval: &Value) {
         match dump_field {
             DumpField::Common(_) => continue,
             DumpField::FieldId(field_id) => {
-                let rc = model::CgroupModel::get_render_config_for_dump(&field_id);
+                let rc = model::SingleCgroupModel::get_render_config_for_dump(&field_id);
                 assert_eq!(
-                    rc.render(model.query(&field_id), false),
+                    rc.render(model.data.query(&field_id), false),
                     jval[rc.render_title(false)]
                         .as_str()
                         .unwrap_or_else(|| panic!(
@@ -444,7 +444,7 @@ fn test_dump_cgroup_titles() {
         .filter_map(|dump_field| match dump_field {
             DumpField::Common(_) => None,
             DumpField::FieldId(field_id) => {
-                let rc = model::CgroupModel::get_render_config_for_dump(&field_id);
+                let rc = model::SingleCgroupModel::get_render_config_for_dump(&field_id);
                 Some(rc.render_title(false))
             }
         })
